@@ -25,7 +25,7 @@ class App extends Component<{}> {
     return (
       <View style={styles.container}>
         <Text style={styles.welcome}>
-          This is BeNoIt app !
+          This is ToTo app !
         </Text>
         <Text style={styles.instructions}>
           Wanna get started ? Edit App.js
